pub struct ZstandardFrameHeader {
pub frame_descriptor: ZstandardFrameDescriptor,
pub window_descriptor: Option<u8>,
pub did: Vec<u8>,
pub frame_content_size: Vec<u8>,
}Expand description
A Zstandard Frame header.
This doesn’t include the blocks and checksum, so you need to do your own accounting and parse
the blocks until the last, then read the checksum if it’s present. See ZstandardFrame for
an easier interface, at the cost of loading all the blocks in memory.
Fields
frame_descriptor: ZstandardFrameDescriptorwindow_descriptor: Option<u8>Minimum memory needed to decode the frame.
did: Vec<u8>frame_content_size: Vec<u8>Original (uncompressed) size.
This field is optional.
This needs to be interpreted before it can be used. See [ZstandardFrame::size()].
Implementations
Sourceimpl ZstandardFrameHeader
impl ZstandardFrameHeader
Sourcepub fn uncompressed_size(&self) -> u64
pub fn uncompressed_size(&self) -> u64
The uncompressed length of the frame’s content in bytes.
Sourcepub fn dictionary_id(&self) -> u32
pub fn dictionary_id(&self) -> u32
The dictionary ID as an integer.